referrerpolicy=no-referrer-when-downgrade

Create

Trait Create 

pub trait Create<AccountId>: Inspect<AccountId> {
    // Required method
    fn create(
        admin: AccountId,
        is_sufficient: bool,
        min_balance: Self::Balance,
    ) -> DispatchResult;
}
Trait for providing the ability to create a new fungible asset.

Required Methods

fn create( admin: AccountId, is_sufficient: bool, min_balance: Self::Balance, ) -> DispatchResult

Create a new fungible asset.

  • admin: The account that will be set as the admin of the asset.
  • is_sufficient: If true, the asset is sufficient and an account can exist with a zero balance. If false, the asset is non-sufficient and accounts must have a minimum balance.
  • min_balance: The minimum balance required for non-sufficient assets.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<F: Create<AccountId>, A: Get<<F as Inspect<AccountId>>::AssetId>, AccountId> Create<AccountId> for ItemOf<F, A, AccountId>

Adapter implementation of super::lifetime::Create for ItemOf.

See the original trait documentation for information on item meaning and usage.