pub trait Create<AccountId>: Inspect<AccountId> {
// Required method
fn create(
admin: AccountId,
is_sufficient: bool,
min_balance: Self::Balance,
) -> DispatchResult;
}Expand description
Trait for providing the ability to create a new fungible asset.
Required Methods
Sourcefn create(
admin: AccountId,
is_sufficient: bool,
min_balance: Self::Balance,
) -> DispatchResult
fn create( admin: AccountId, is_sufficient: bool, min_balance: Self::Balance, ) -> DispatchResult
Create a new fungible asset.
admin: The account that will be set as the admin of the asset.is_sufficient: Iftrue, the asset is sufficient and an account can exist with a zero balance. Iffalse, the asset is non-sufficient and accounts must have a minimum balance.min_balance: The minimum balance required for non-sufficient assets.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.